Confidence Interval of the Output of 'cond_indirect_diff()'
Source:R/cond_indirect_diff.R
confint.cond_indirect_diff.RdExtract the confidence
interval the output of
cond_indirect_diff().
Usage
# S3 method for class 'cond_indirect_diff'
confint(object, parm, level = NULL, ...)Arguments
- object
The output of
cond_indirect_diff().- parm
Ignored.
- level
If set to
NULL, the default, then the level of confidence used to generateobjectis used. If set to a value, this value will be used to recompute the confidence intervals. If the confidence interval is to be computed from the standard error, and solevelis not set inobject, then the default value is .95. (This new behavior applies to 0.3.6.15 and later version.)- ...
Optional arguments. Ignored.